# WebWatchr Documentation

This documentation will grow as the project grows. For the moment, you can find all available information in the [README.md](https://github.com/Emrys-Merlin/web_watchr) on the github page and in the [API Reference](api.md).
